# Auto-generated full reflection for com.android.billingclient.api.ProductDetails$RecurrenceMode
# Source: javap -s output
__all__ = ("RecurrenceMode",)

from jnius import JavaClass, MetaJavaClass, JavaStaticField


class RecurrenceMode(JavaClass, metaclass=MetaJavaClass):
    __javaclass__ = "com/android/billingclient/api/ProductDetails$RecurrenceMode"

    # static fields
    FINITE_RECURRING = JavaStaticField("I")
    INFINITE_RECURRING = JavaStaticField("I")
    NON_RECURRING = JavaStaticField("I")



from jnius import JavaClass, MetaJavaClass, JavaStaticMethod

__all__ = ("ConsumeParams",)


class ConsumeParams(JavaClass, metaclass=MetaJavaClass):
    __javaclass__ = "com/android/billingclient/api/ConsumeParams"
    newBuilder = JavaStaticMethod("()Lcom/android/billingclient/api/ConsumeParams$Builder;")



from jnius import PythonJavaClass, java_method

__all__ = ("AcknowledgePurchaseResponseListener", )


class AcknowledgePurchaseResponseListener(PythonJavaClass):
    __javainterfaces__ = ["com/android/billingclient/api/AcknowledgePurchaseResponseListener"]
    __javacontext__ = "app"

    def __init__(self, callback):
        self.callback = callback

    @java_method("(Lcom/android/billingclient/api/BillingResult;)V")
    def onAcknowledgePurchaseResponse(self, billing_result):
        self.callback(billing_result)



from jnius import PythonJavaClass, java_method

__all__ = ("ProductDetailsResponseListener", )


class ProductDetailsResponseListener(PythonJavaClass):
    __javainterfaces__ = ["com/android/billingclient/api/ProductDetailsResponseListener"]
    __javacontext__ = "app"

    def __init__(self, callback):
        self.callback = callback

    @java_method("(Lcom/android/billingclient/api/BillingResult;"
                 "Lcom/android/billingclient/api/QueryProductDetailsResult;)V")
    def onProductDetailsResponse(self, billing_result, product_details_result):
        self.callback(billing_result, product_details_result)



from jnius import JavaClass, MetaJavaClass, JavaStaticMethod, JavaMethod, JavaStaticField

__all__ = ("PendingPurchasesParams", "PendingPurchasesParamsBuilder", "Purchase", "PurchaseState", "PendingPurchaseUpdate")


class PendingPurchasesParams(JavaClass, metaclass=MetaJavaClass):
    __javaclass__ = "com/android/billingclient/api/PendingPurchasesParams"
    newBuilder = JavaStaticMethod("()Lcom/android/billingclient/api/PendingPurchasesParams$Builder;")


class PendingPurchasesParamsBuilder(JavaClass, metaclass=MetaJavaClass):
    __javaclass__ = "com/android/billingclient/api/PendingPurchasesParams$Builder"

    build = JavaMethod("()Lcom/android/billingclient/api/PendingPurchasesParams;")
    enableOneTimeProducts = JavaMethod("()Lcom/android/billingclient/api/PendingPurchasesParams$Builder;")
    enablePrepaidPlans = JavaMethod("()Lcom/android/billingclient/api/PendingPurchasesParams$Builder;")


class Purchase(JavaClass, metaclass=MetaJavaClass):
    __javaclass__ = "com/android/billingclient/api/Purchase"

    getAccountIdentifiers = JavaMethod("()Lcom/android/billingclient/api/AccountIdentifiers;")
    getDeveloperPayload = JavaMethod("()Ljava/lang/String;")
    getOrderId = JavaMethod("()Ljava/lang/String;")
    getOriginalJson = JavaMethod("()Ljava/lang/String;")
    getPackageName = JavaMethod("()Ljava/lang/String;")
    getPendingPurchaseUpdate = JavaMethod("()Lcom/android/billingclient/api/Purchase$PendingPurchaseUpdate;")
    getProducts = JavaMethod("()Ljava/util/List;")
    getPurchaseState = JavaMethod("()I")
    getPurchaseTime = JavaMethod("()J")
    getPurchaseToken = JavaMethod("()Ljava/lang/String;")
    getQuantity = JavaMethod("()I")
    getSignature = JavaMethod("()Ljava/lang/String;")
    hashCode = JavaMethod("()I")
    isAcknowledged = JavaMethod("()Z")
    isAutoRenewing = JavaMethod("()Z")
    toString = JavaMethod("()Ljava/lang/String;")


class PurchaseState(JavaClass, metaclass=MetaJavaClass):
    __javaclass__ = "com/android/billingclient/api/Purchase$PurchaseState"

    # Purchase state constants
    PENDING = JavaStaticField("I")
    PURCHASED = JavaStaticField("I")
    UNSPECIFIED = JavaStaticField("I")


class PendingPurchaseUpdate(JavaClass, metaclass=MetaJavaClass):
    __javaclass__ = "com/android/billingclient/api/Purchase$PendingPurchaseUpdate"

    getProducts = JavaMethod("()Ljava/util/List;")
    getPurchaseToken = JavaMethod("()Ljava/lang/String;")




__all__ = ("is_jnull", "QueryDict")

from jnius import autoclass


def is_jnull(obj):
    Objects = autoclass("java.util.Objects")
    return Objects.isNull(obj)


class QueryDict(dict):
    '''QueryDict is a dict() that can be queried with dot.

    ::

        d = QueryDict()
        # create a key named toto, with the value 1
        d.toto = 1
        # it's the same as
        d['toto'] = 1

    .. versionadded:: 1.0.4
    '''

    def __getattr__(self, attr):
        try:
            return self.__getitem__(attr)
        except KeyError:
            raise AttributeError("%r object has no attribute %r" % (
                self.__class__.__name__, attr))

    def __setattr__(self, attr, value):
        self.__setitem__(attr, value)



from jnius import JavaClass, MetaJavaClass, JavaStaticMethod, JavaMethod

__all__ = ("QueryProductDetailsParams", "QueryProductDetailsParamsProduct", "QueryProductDetailsParamsBuilder", "QueryProductDetailsParamsProductBuilder")


class QueryProductDetailsParams(JavaClass, metaclass=MetaJavaClass):
    __javaclass__ = "com/android/billingclient/api/QueryProductDetailsParams"
    newBuilder = JavaStaticMethod("()Lcom/android/billingclient/api/QueryProductDetailsParams$Builder;")


class QueryProductDetailsParamsProduct(JavaClass, metaclass=MetaJavaClass):
    __javaclass__ = "com/android/billingclient/api/QueryProductDetailsParams$Product"
    newBuilder = JavaStaticMethod("()Lcom/android/billingclient/api/QueryProductDetailsParams$Product$Builder;")


class QueryProductDetailsParamsProductBuilder(JavaClass, metaclass=MetaJavaClass):
    __javaclass__ = "com/android/billingclient/api/QueryProductDetailsParams$Product$Builder"
    build = JavaMethod("()Lcom/android/billingclient/api/QueryProductDetailsParams$Product;")
    setProductId = JavaMethod("(Ljava/lang/String;)"
                              "Lcom/android/billingclient/api/QueryProductDetailsParams$Product$Builder;")
    setProductType = JavaMethod("(Ljava/lang/String;)"
                                "Lcom/android/billingclient/api/QueryProductDetailsParams$Product$Builder;")


class QueryProductDetailsParamsBuilder(JavaClass, metaclass=MetaJavaClass):
    __javaclass__ = "com/android/billingclient/api/QueryProductDetailsParams$Builder"
    build = JavaMethod("()Lcom/android/billingclient/api/QueryProductDetailsParams;")
    setProductList = JavaMethod("(Ljava/util/List;)Lcom/android/billingclient/api/QueryProductDetailsParams$Builder;")


class QueryProductDetailsResult(JavaClass, metaclass=MetaJavaClass):
    __javaclass__ = "com/android/billingclient/api/QueryProductDetailsResult"
    create = JavaStaticMethod("(Ljava/util/List;Ljava/util/List;)"
                              "Lcom/android/billingclient/api/QueryProductDetailsResult;")
    getProductDetailsList = JavaMethod("()Ljava/util/List;")
    getUnfetchedProductList = JavaMethod("()Ljava/util/List;")



from jnius import PythonJavaClass, java_method

__all__ = ("ConsumeResponseListener", )


class ConsumeResponseListener(PythonJavaClass):
    __javainterfaces__ = ["com/android/billingclient/api/ConsumeResponseListener"]
    __javacontext__ = "app"

    def __init__(self, callback):
        self.callback = callback

    @java_method("(Lcom/android/billingclient/api/BillingResult;Ljava/lang/String;)V")
    def onConsumeResponse(self, billing_result, purchase_token):
        self.callback(billing_result, purchase_token)



from jnius import JavaClass, MetaJavaClass, JavaStaticMethod

__all__ = ("AcknowledgePurchaseParams",)


class AcknowledgePurchaseParams(JavaClass, metaclass=MetaJavaClass):
    __javaclass__ = "com/android/billingclient/api/AcknowledgePurchaseParams"
    newBuilder = JavaStaticMethod("()Lcom/android/billingclient/api/AcknowledgePurchaseParams$Builder;")
